repo
stringclasses
15 values
fix_commit
stringlengths
40
40
buggy_commit
stringlengths
40
40
message
stringlengths
3
64.3k
files
listlengths
1
300
timestamp
timestamp[s]date
2013-03-13 20:45:00
2026-04-11 07:48:46
ggml-org/llama.cpp
3a5cb629b180a074e02056a40695528a2171254c
8cc2d81264c6089ae86fc25a9f7e6e75114d3590
vulkan: async and event fixes (#20518) * vulkan: fix event wait submission, event command buffer reset * fix event command buffer reset validation error * also reset command buffers before reuse * use timeline semaphores instead of fences for event_synchronize * don't use initializer list for semaphore wait info ...
[ { "path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp", "patch": "@@ -191,6 +191,7 @@ struct vk_queue;\n \n struct vk_command_buffer {\n vk::CommandBuffer buf;\n+ uint64_t use_counter = 0;\n bool in_use = false;\n };\n \n@@ -938,19 +939,24 @@ struct vk_subbuffer {\n }\n };\n \n-// vk_event is used ...
2026-03-17T13:27:23
golang/go
fd0294b99c2def6a5def7fde9793c2e57ca04240
eeddabcadb06a2161c379954e31ccfad6a75fc86
cmd/internal/obj/arm64: recognize FIPS static temps as unaligned Code like x := [12]byte{1,2,3,4,5,6,7,8,9,10,11,12} stores x in a pair of registers and uses MOVD/MOVWU to load the values from RODATA. The code generator needs to understand not to use the aligned PC-relative relocation for that sequence. In non-FIPS m...
[ { "path": "src/cmd/internal/obj/arm64/asm7.go", "patch": "@@ -1073,15 +1073,49 @@ func (o *Optab) size(ctxt *obj.Link, p *obj.Prog) int {\n \t\t// 2-byte and 1-byte aligned addresses, so the address of load/store must be aligned.\n \t\t// Also symbols with prefix of \"go:string.\" are Go strings, which will...
2024-11-17T16:51:52
ollama/ollama
2192a28eedc24398c7f274a15617341389b6c143
5d81c1a1842712e218d0311546037d152502b2c0
ml/backend/ggml: fix rms norm
[ { "path": "ml/backend/ggml/ggml.go", "patch": "@@ -485,7 +485,7 @@ func (t *Tensor) LayerNorm(ctx ml.Context, w, b ml.Tensor, eps float32) ml.Tenso\n }\n \n func (t *Tensor) RMSNorm(ctx ml.Context, w ml.Tensor, eps float32) ml.Tensor {\n-\treturn (&Tensor{t: C.ggml_norm(ctx.(*Context).ctx, t.t, C.float(eps)...
2025-02-21T00:45:05
electron/electron
2a8d49a0591a74b3732717ce52724e38f0e73055
6e6f5efad95e6899694484ea8da1e5dcc67b3992
fix: maximize/unmaximize firing on linux (#32441)
[ { "path": "shell/browser/ui/x/window_state_watcher.cc", "patch": "@@ -21,7 +21,9 @@ WindowStateWatcher::WindowStateWatcher(NativeWindowViews* window)\n x11::GetAtom(\"_NET_WM_STATE_MAXIMIZED_VERT\")),\n net_wm_state_maximized_horz_atom_(\n x11::GetAtom(\"_NET_WM_STATE_MAXIMIZED_HOR...
2022-01-17T07:46:52
ggml-org/llama.cpp
8cc2d81264c6089ae86fc25a9f7e6e75114d3590
627670601a64569d9d822c8d52a8ff39ed69cce5
server : fix ctx checkpoint invalidation (#20671)
[ { "path": "tools/server/server-context.cpp", "patch": "@@ -2402,11 +2402,11 @@ struct server_context_impl {\n }\n \n {\n- // erase any checkpoints with pos_min > pos_min_thold\n+ // erase an...
2026-03-17T13:21:14
vuejs/vue
78ef6271d237e83fbd647567f2b79a5786f09d3d
6149048ce95bda9be7c14abed45859b743842ce7
test: upgrade vitest + fix ssr tests for Node 18+
[ { "path": "package.json", "patch": "@@ -99,7 +99,7 @@\n \"conventional-changelog-cli\": \"^2.2.2\",\n \"cross-spawn\": \"^7.0.3\",\n \"enquirer\": \"^2.3.6\",\n- \"esbuild\": \"^0.14.43\",\n+ \"esbuild\": \"^0.19.5\",\n \"execa\": \"^4.1.0\",\n \"he\": \"^1.2.0\",\n \"jasmine-c...
2023-10-22T02:32:47
golang/go
eeddabcadb06a2161c379954e31ccfad6a75fc86
050109c4fba02652007a4e7bfac9404ef334721a
crypto/md5,crypto/sha512: fix AppendBinary -> BinaryAppender docs typo Change-Id: Ia2caecd0a54e1100ad523f0dc76f17babcd0ffca Reviewed-on: https://go-review.googlesource.com/c/go/+/626878 Reviewed-by: Daniel McCarney <daniel@binaryparadox.net> Reviewed-by: Russ Cox <rsc@golang.org> Auto-Submit: Filippo Valsorda <filippo...
[ { "path": "src/crypto/md5/md5.go", "patch": "@@ -99,7 +99,7 @@ func consumeUint32(b []byte) ([]byte, uint32) {\n }\n \n // New returns a new [hash.Hash] computing the MD5 checksum. The Hash\n-// also implements [encoding.BinaryMarshaler], [encoding.AppendBinary] and\n+// also implements [encoding.BinaryMars...
2024-11-10T10:07:25
ollama/ollama
14b5a9a150598d724e4ef17616cdb25257ddc155
ba9ec3d05ed47b243389f8273d160329e8964362
api: document client stream behavior with a test (#8996) Added unit tests to verify error handling behavior in the Client.stream and Client.do methods. Tests cover various error scenarios including: - Error responses with status codes >= 400 - Error messages with successful status codes - Empty error messages - Succes...
[ { "path": "api/client.go", "patch": "@@ -132,7 +132,7 @@ func (c *Client) do(ctx context.Context, method, path string, reqData, respData\n const maxBufferSize = 512 * format.KiloByte\n \n func (c *Client) stream(ctx context.Context, method, path string, data any, fn func([]byte) error) error {\n-\tvar buf *...
2025-02-20T21:19:58
huggingface/transformers
aefa23ad1c52de9c115f3d762fe1a1eda643275a
8012fde3579718f750ef2bd5fd0e8ddf6bcabd6c
🚨 Refactor DETR to updated standards (#41549) * refactor attention and many other * remove return_dict interface * improve variable names * use _can_record_outputs and add real support for pixel and queries masks, vision input embeds and query embeds * split self attention and cross attention * nits * standardi...
[ { "path": "src/transformers/conversion_mapping.py", "patch": "@@ -62,6 +62,8 @@\n \"hunyuan_v1_moe\": \"qwen2_moe\",\n \"flex_olmo\": \"qwen2_moe\",\n \"olmoe\": \"qwen2_moe\",\n+ \"rt_detr_v2\": \"rt_detr\",\n+ \"pp_doclayout_v3\": \"rt_detr\",\n }\n \n \n@@ -224,6 +226,52 @@ def _build_c...
2026-02-02T23:42:50
electron/electron
6e6f5efad95e6899694484ea8da1e5dcc67b3992
fac61122d560029c9b5f59852d08857f6855d70c
fix: re-enable PartitionAlloc on macOS (#32442) * fix: re-enable PartitionAlloc on macOS * no need to copy ignore_result on linux * factor out FixStdioStreams * include buildflags.h in electron_main_linux * #include electron/fuses * more missing includes
[ { "path": "BUILD.gn", "patch": "@@ -900,8 +900,12 @@ if (is_mac) {\n deps += [ \"//sandbox/mac:seatbelt\" ]\n }\n defines = [ \"HELPER_EXECUTABLE\" ]\n- sources = filenames.app_sources\n- sources += [ \"shell/common/electron_constants.cc\" ]\n+ sources = [\n+ \"shel...
2022-01-17T07:46:33
ggml-org/llama.cpp
627670601a64569d9d822c8d52a8ff39ed69cce5
740a447fc38e6578a69bb578380c86998d75e286
kleidiai : fix MUL_MAT support for batched (3D) inputs (#20620) * kleidiai : fix MUL_MAT support for batched (3D) inputs The supports_op() check incorrectly rejected MUL_MAT operations with 3D inputs (ne[2] > 1), but the actual compute_forward_qx() implementation handles batched inputs correctly via a loop over ne12....
[ { "path": "ggml/src/ggml-cpu/kleidiai/kleidiai.cpp", "patch": "@@ -1461,7 +1461,7 @@ class extra_buffer_type : ggml::cpu::extra_buffer_type {\n return false;\n }\n if ((op->src[1]->type == GGML_TYPE_F32 || op->src[1]->type == GGML_TYPE_I32) &&\n- ggml_n...
2026-03-17T12:03:54
vuejs/vue
d52fbff7a77d8d9c032a74a21c34e2c122add5d9
0e8511a8becf627e00443bd799dd99e5fd1b8a35
chore: fix typo in utils.ts (#12927) [skip ci]
[ { "path": "src/types/utils.ts", "patch": "@@ -1,3 +1,3 @@\n-// If the the type T accepts type \"any\", output type Y, otherwise output type N.\n+// If the type T accepts type \"any\", output type Y, otherwise output type N.\n // https://stackoverflow.com/questions/49927523/disallow-call-with-any/49928360#49...
2023-01-12T14:47:00
golang/go
405a0c4ae86fe2761118ee6d1d59e59daf9b50cd
afa98806389ed935264b67eb7e90507a334180f2
os/user: fix race detector failure The race detector doesn't like that windows.GetSid* functions return pointers to the SID structure. This change makes these functions return values instead and mark them with nocheckptr. Fixes #70378 Cq-Include-Trybots: luci.golang.try:gotip-windows-amd64-race Change-Id: Iba39d75bb...
[ { "path": "src/internal/syscall/windows/security_windows.go", "patch": "@@ -5,6 +5,7 @@\n package windows\n \n import (\n+\t\"runtime\"\n \t\"syscall\"\n \t\"unsafe\"\n )\n@@ -231,6 +232,33 @@ var SECURITY_NT_AUTHORITY = SID_IDENTIFIER_AUTHORITY{\n }\n \n //sys\tIsValidSid(sid *syscall.SID) (valid bool) = a...
2024-11-18T08:31:59
huggingface/transformers
56c4b5e37f92b4ee8716beca3b26dee5c5e63dc5
78e4f885286fc8c811685c5a59178e579b9e5879
🚨Fix floating-point precision in JanusImageProcessor resize (#43187) * Fix floating-point precision in JanusImageProcessor resize * Regenerate image_processing_janus.py from modular file * Fix int() truncation in deepseek_vl and janus_fast * fix-repo * fix integration tests --------- Co-authored-by: yonigozlan ...
[ { "path": "src/transformers/models/deepseek_vl/image_processing_deepseek_vl.py", "patch": "@@ -189,8 +189,8 @@ def resize(\n delta = size / max_size\n # Largest side becomes `size` and the other side is scaled according to the aspect ratio.\n output_size_nonpadded = [\n- m...
2026-02-02T18:47:33
ollama/ollama
7c168b08c9522f56290478fba0267118d20f7ec4
3d4cc7833c21bf9189cb1d3fa8365997e46fad33
server: add missing function parens to debug log (#9255)
[ { "path": "server/sched.go", "patch": "@@ -179,7 +179,7 @@ func (s *Scheduler) processPending(ctx context.Context) {\n \t\t\t\t\t\tif allReliable {\n \t\t\t\t\t\t\t// HACK\n \t\t\t\t\t\t\tos.Setenv(\"OLLAMA_MAX_LOADED_MODELS\", strconv.Itoa(defaultModelsPerGPU*len(gpus)))\n-\t\t\t\t\t\t\tslog.Debug(\"updati...
2025-02-20T20:10:15
ggml-org/llama.cpp
d34ff7eb5ba289bd61f659c8f3f48c983c3ce4f8
45172df4d6843a903ad7dcb84c83388094f896bb
model: mistral small 4 support (#20649) * model: mistral small 4 support * fix test * fix test (2) * Apply suggestions from code review Co-authored-by: Sigbjørn Skjæret <sigbjorn.skjaeret@scala.com> * Update convert_hf_to_gguf.py Co-authored-by: Sigbjørn Skjæret <sigbjorn.skjaeret@scala.com> * change newline -...
[ { "path": "convert_hf_to_gguf.py", "patch": "@@ -298,11 +298,16 @@ def dequant_simple(weight: Tensor, scale: Tensor, block_size: Sequence[int] | No\n scale = scale.float()\n \n if block_size is not None:\n+ dim_offset = scale.ndim - len(block_size)\n ...
2026-03-16T23:31:14
electron/electron
fac61122d560029c9b5f59852d08857f6855d70c
868794a6bd03e08124c745be15896ed67e9a5e30
docs: fix anchors for broken relative links (#32478)
[ { "path": "docs/api/browser-window.md", "patch": "@@ -996,7 +996,7 @@ APIs like `win.setSize`.\n is `true`). Default is `#FFF` (white).\n \n Sets the background color of the window. See [Setting\n-`backgroundColor`](#setting-backgroundcolor).\n+`backgroundColor`](#setting-the-backgroundcolor-property).\n ...
2022-01-17T07:36:19
golang/go
bc1da38c3d29b4950b302b36fd180bf86bdcb45c
44cea1234dc18352fec89285e94f92693034323d
crypto/subtle: add DIT closure Add a new function, WithDataIndependentTiming, which takes a function as an argument, and encloses it with calls to set/unset the DIT PSTATE bit on Arm64. Since DIT is OS thread-local, for the duration of the execution of WithDataIndependentTiming, we lock the goroutine to the OS thread...
[ { "path": "api/next/66450.txt", "patch": "@@ -0,0 +1 @@\n+pkg crypto/subtle, func WithDataIndependentTiming(func()) #66450", "additions": 1, "deletions": 0, "language": "Plain Text" }, { "path": "doc/godebug.md", "patch": "@@ -177,6 +177,17 @@ This behavior can be controlled with the...
2024-07-15T17:05:37
vuejs/vue
0e8511a8becf627e00443bd799dd99e5fd1b8a35
34c6192f4a5d0471da5655ebcf111653fd920172
chore: fix typo in apiAsyncComponent.ts (#12912)
[ { "path": "src/v3/apiAsyncComponent.ts", "patch": "@@ -47,7 +47,7 @@ export function defineAsyncComponent(\n \n if (__DEV__ && suspensible) {\n warn(\n- `The suspensiblbe option for async components is not supported in Vue2. It is ignored.`\n+ `The suspensible option for async components is ...
2022-12-27T21:38:05
huggingface/transformers
78e4f885286fc8c811685c5a59178e579b9e5879
a9cf5e533981e0c9c2b0a9c7271a392b36345004
Docs: fix typos in Get started (index, quicktour) (#43666) - index.md: "multimodal model" → "multimodal models" - quicktour.md: "Pytorch" → "PyTorch"
[ { "path": "docs/source/en/index.md", "patch": "@@ -20,7 +20,7 @@ rendered properly in your Markdown viewer.\n </h3>\n \n Transformers acts as the model-definition framework for state-of-the-art machine learning models in text, computer\n-vision, audio, video, and multimodal model, for both inference and tra...
2026-02-02T17:47:52
ggml-org/llama.cpp
c0ccbd1f86ee4c0957e505d49fabea4253d24632
f6da02c3f2083becf96f6ba5e26c70cfb15897fb
ggml : try fix arm build (whisper/0)
[ { "path": "ggml/src/ggml-cpu/arch/arm/quants.c", "patch": "@@ -666,7 +666,7 @@ void ggml_vec_dot_nvfp4_q8_0(int n, float * GGML_RESTRICT s, size_t bs, const vo\n \n float sumf = 0;\n \n-#if defined __ARM_NEON\n+#if defined(__ARM_NEON) && defined(__ARM_FEATURE_FMA)\n const int8x16_t values = vld1q_s8...
2026-03-16T07:11:13
ollama/ollama
d2eb226c914aa86f2a371c340997d6e26e2aecef
e13e7c8d9496d26dea74ec2ccdbb731ee998bca6
llama: add patch to fix ggml backend reg on Linux with utf-8 characters in the path (#9159)
[ { "path": "llama/patches/0018-use-std-filesystem-path-instead-of-wstring.patch", "patch": "@@ -0,0 +1,285 @@\n+From 0000000000000000000000000000000000000000 Mon Sep 17 00:00:00 2001\n+From: jmorganca <jmorganca@gmail.com>\n+Date: Sun, 16 Feb 2025 20:00:22 -0500\n+Subject: [PATCH] use std::filesystem::path i...
2025-02-19T03:46:17
electron/electron
f75a2740190fd9770120830a5a6b6e86d2360734
7f4efb67472cdc05d277754ee5f95f0f83247125
fix: Corrupted title of alert dialog (#32434)
[ { "path": "shell/browser/ui/message_box_win.cc", "patch": "@@ -171,8 +171,9 @@ DialogResult ShowTaskDialogWstr(NativeWindow* parent,\n \n // TaskDialogIndirect doesn't allow empty name, if we set empty title it\n // will show \"electron.exe\" in title.\n+ std::wstring app_name;\n if (title.empty()) {...
2022-01-13T21:23:36
vuejs/vue
ca11dc6a86f26accc893c1ce5b611dc84a2e7c2d
9dd006b481b4299462e044741bac0861c0b1775c
chore: fix typo (#12894)
[ { "path": "src/core/observer/index.ts", "patch": "@@ -19,7 +19,7 @@ import { isReadonly, isRef, TrackOpTypes, TriggerOpTypes } from '../../v3'\n \n const arrayKeys = Object.getOwnPropertyNames(arrayMethods)\n \n-const NO_INIITIAL_VALUE = {}\n+const NO_INITIAL_VALUE = {}\n \n /**\n * In some cases we may wa...
2022-12-06T14:35:28
golang/go
f916d93e415068e0ec286249f96e6164ad822731
380903588cc68dbdcf35c839a9fd4b1ec2cc2158
crypto/cipher: add NewGCMWithRandomNonce Fixes #69981 Change-Id: I0cad11f5d7673304c5a6d85fc598ddc27ab93738 Reviewed-on: https://go-review.googlesource.com/c/go/+/629175 LUCI-TryBot-Result: Go LUCI <golang-scoped@luci-project-accounts.iam.gserviceaccount.com> Auto-Submit: Filippo Valsorda <filippo@golang.org> Reviewed...
[ { "path": "api/next/69981.txt", "patch": "@@ -0,0 +1 @@\n+pkg crypto/cipher, func NewGCMWithRandomNonce(Block) (AEAD, error) #69981", "additions": 1, "deletions": 0, "language": "Plain Text" }, { "path": "doc/next/6-stdlib/99-minor/crypto/cipher/69981.md", "patch": "@@ -0,0 +1,3 @@\n...
2024-11-18T15:19:12
ggml-org/llama.cpp
f6da02c3f2083becf96f6ba5e26c70cfb15897fb
dddca026bf64ae312cc8b5144ce2fc0e1d0a51e4
ggml : extend im2col f16 (ggml/1434) * examples/yolo: fix load_model memory leak * fix/issue-1433 ggml_compute_forward_im2col_f16 assert error * fix/issue-1433
[ { "path": "ggml/src/ggml-cpu/ops.cpp", "patch": "@@ -6205,7 +6205,7 @@ static void ggml_compute_forward_im2col_f16(\n const ggml_tensor * src1 = dst->src[1];\n \n GGML_ASSERT(src0->type == GGML_TYPE_F16);\n- GGML_ASSERT(src1->type == GGML_TYPE_F32);\n+ GGML_ASSERT(src1->type == GGML_TYPE_F16 |...
2026-03-15T19:50:56
huggingface/transformers
f12b50a09220260697f62400a921c6e596246c0a
41771ce4a10e5e99e8ece88918d6307dc0cca286
custom tok init fix (#43591) * custom tok init fix * test * pin rev * ruff * ruff2
[ { "path": "src/transformers/tokenization_python.py", "patch": "@@ -415,6 +415,9 @@ def __init__(self, **kwargs):\n \n self.tokens_trie = Trie()\n \n+ # Initialize total_vocab_size early to avoid issues if get_vocab() is called early (custom tokenizers)\n+ self.total_vocab_size = 0\n+\n...
2026-02-02T17:00:07
vuejs/vue
29b5f588032600baae9854ac9a4105916a5aa648
d1899caf688de961e63e7a0d56f806fc4a12efd9
fix(reactivity): avoid using WeakMap for IE compatibility Using a WeakMap polyfill isn't ideal because the reason we tried to use WeakMap was to work with non-extensible objects. However, WeakMap polyfill for non-extensible objects are non-weak and could lead to memory leaks. The trade-off is that we remove support f...
[ { "path": "src/core/observer/index.ts", "patch": "@@ -16,7 +16,6 @@ import {\n noop\n } from '../util/index'\n import { isReadonly, isRef, TrackOpTypes, TriggerOpTypes } from '../../v3'\n-import { rawMap } from '../../v3/reactivity/reactive'\n \n const arrayKeys = Object.getOwnPropertyNames(arrayMethods)\...
2022-11-09T12:33:05
golang/go
bedde1bee0ce16b46549d182375f4feb3b137f46
e66229a22af8b4895193aacaf95828de63575957
crypto: check all cpu.X86 flags for features used in assembly These are most likely redundant, but cmd/compile/internal/amd64's TestGoAMD64v1 turns them off when clobbering those instructions, so we need to know to skip the assembly in those cases. Thankfully we have Avo now that adds a helpful comment with the list ...
[ { "path": "src/cmd/compile/internal/amd64/versions_test.go", "patch": "@@ -78,7 +78,7 @@ func TestGoAMD64v1(t *testing.T) {\n \tcmd.Env = append(cmd.Env, fmt.Sprintf(\"GODEBUG=%s\", strings.Join(features, \",\")))\n \tout, err := cmd.CombinedOutput()\n \tif err != nil {\n-\t\tt.Fatalf(\"couldn't execute tes...
2024-11-09T18:16:13
electron/electron
7f4efb67472cdc05d277754ee5f95f0f83247125
6c88e3b8e71408e095446a4e956e4cb087066041
fix: desktop screen capture on macOS not releasing (#32435)
[ { "path": "patches/chromium/desktop_media_list.patch", "patch": "@@ -82,7 +82,7 @@ index 1e4a652634fbde2ca9a256baca840bbc5a0e001f..546f5bc3a2f79035f0eec196d9e704b8\n const Source& GetSource(int index) const override;\n DesktopMediaList::Type GetMediaListType() const override;\n diff --git a/chrome/bro...
2022-01-13T15:21:28
ggml-org/llama.cpp
67a2209fabe2e3498d458561933d5380655085d2
d65c4f2dc9e380317c2fed804b7d98a758ca0886
webui: Add MCP CORS Proxy detection logic & UI (#20167) * refactor: MCP store cleanup * feat: Add MCP proxy availability detection * fix: Sidebar icon * chore: update webui build output * chore: Formatting * chore: update webui build output * chore: Update package lock * chore: update webui build output * chor...
[ { "path": "tools/server/webui/package-lock.json", "patch": "@@ -939,7 +939,6 @@\n \t\t\t\"integrity\": \"sha512-oJrXtQiAXLvT9clCf1K4kxp3eKsQhIaZqxEyowkBcsvZDdZkbWrVmnGknxs5flTD0VGsxrxKgBCZty1EzoiMzA==\",\n \t\t\t\"dev\": true,\n \t\t\t\"license\": \"Apache-2.0\",\n-\t\t\t\"peer\": true,\n \t\t\t\"dependenci...
2026-03-16T12:05:36
huggingface/transformers
41771ce4a10e5e99e8ece88918d6307dc0cca286
559af4457ccf43aaa0dcd5313248a14e8db6430b
More export friendly rewrites and skipping the failing ones (#43436) * more dynamo best practices * skip models that fail torch export * fix repo * fix * avoid len * Apply suggestion from @IlyasMoutawwakil * fix export for all mamba ssms * fix time series models * less flaky tests * pass pe audio * final fi...
[ { "path": "src/transformers/models/bamba/modeling_bamba.py", "patch": "@@ -41,7 +41,7 @@\n from ...modeling_rope_utils import ROPE_INIT_FUNCTIONS, dynamic_rope_update\n from ...modeling_utils import ALL_ATTENTION_FUNCTIONS, PreTrainedModel\n from ...processing_utils import Unpack\n-from ...utils import Tran...
2026-02-02T16:56:09
vuejs/vue
d1899caf688de961e63e7a0d56f806fc4a12efd9
5e3d4e90cdf92ec0a72bbb2bd44125f1faafae1d
fix(provide/inject): do not mutate original provide options during merge fix #12854
[ { "path": "src/core/util/options.ts", "patch": "@@ -51,7 +51,8 @@ if (__DEV__) {\n */\n function mergeData(\n to: Record<string | symbol, any>,\n- from: Record<string | symbol, any> | null\n+ from: Record<string | symbol, any> | null,\n+ recursive = true\n ): Record<PropertyKey, any> {\n if (!from) ...
2022-11-09T12:04:25
golang/go
b6aada5e81284e48183e0c324afa208bc0e25a4b
aae088b16a327cc4b1a81928c307d5bd6e54849b
doc/godebug: document that unrecognized GODEBUG entries are ignored Change-Id: I6debc82913ae9fa02bee55dc87d35574f5265008 Reviewed-on: https://go-review.googlesource.com/c/go/+/629576 Reviewed-by: Dmitri Shuralyov <dmitshur@golang.org> Reviewed-by: Ian Lance Taylor <iant@google.com> LUCI-TryBot-Result: Go LUCI <golang-...
[ { "path": "doc/godebug.md", "patch": "@@ -34,6 +34,7 @@ For example, if a Go program is running in an environment that contains\n \n then that Go program will disable the use of HTTP/2 by default in both\n the HTTP client and the HTTP server.\n+Unrecognized settings in the `GODEBUG` environment variable are...
2024-11-19T03:27:22
electron/electron
6c88e3b8e71408e095446a4e956e4cb087066041
1aaa0fad694948a1c53355af12fe1e5ccc3e3e3f
fix: optional postMessage transfer arg (#32433)
[ { "path": "shell/browser/api/electron_api_web_frame_main.cc", "patch": "@@ -210,7 +210,7 @@ void WebFrameMain::PostMessage(v8::Isolate* isolate,\n }\n \n std::vector<gin::Handle<MessagePort>> wrapped_ports;\n- if (transfer) {\n+ if (transfer && !transfer.value()->IsUndefined()) {\n if (!gin::Conve...
2022-01-13T13:52:48
ggml-org/llama.cpp
d65c4f2dc9e380317c2fed804b7d98a758ca0886
d8c331c0afb1730a17c4440a924d0f57884245c0
Fix model selector locked to first loaded model with multiple models (#20580) * webui: fix model selector being locked to first loaded model When multiple models are loaded, the auto-select effect would re-fire on every loadedModelIds change, overriding the user's manual model selection. Guard with selectedModelId so...
[ { "path": "tools/server/webui/src/lib/components/app/chat/ChatForm/ChatFormActions/ChatFormActions.svelte", "patch": "@@ -65,7 +65,8 @@\n \t$effect(() => {\n \t\tif (conversationModel) {\n \t\t\tmodelsStore.selectModelByName(conversationModel);\n-\t\t} else if (isRouter && modelsStore.loadedModelIds.length ...
2026-03-16T11:04:06
huggingface/transformers
559af4457ccf43aaa0dcd5313248a14e8db6430b
0294359061c39dfa9f7e64d8eacf4fd7fb173aab
Cast byte_count to int in caching_allocator_warmup for MPS compatibility (#43608) Fix: Cast byte_count to int in caching_allocator_warmup for MPS compatibility
[ { "path": "src/transformers/modeling_utils.py", "patch": "@@ -4728,7 +4728,7 @@ def caching_allocator_warmup(model: PreTrainedModel, expanded_device_map: dict,\n ) - torch_accelerator_module.memory_allocated(index)\n byte_count = int(max(0, byte_count - unused_memory))\n # We...
2026-02-02T16:55:50
vuejs/vue
5e3d4e90cdf92ec0a72bbb2bd44125f1faafae1d
5aed733ab6b6605314cc5f24cc1b1dd9aa4413c8
fix(compiler-sfc): fix template usage check edge case for v-slot destructured default value (#12842) fix #12841
[ { "path": "packages/compiler-sfc/src/compileScript.ts", "patch": "@@ -39,7 +39,7 @@ import { walk } from 'estree-walker'\n import { RawSourceMap } from 'source-map'\n import { warnOnce } from './warn'\n import { isReservedTag } from 'web/util'\n-import { bindRE, dirRE, onRE } from 'compiler/parser'\n+import...
2022-11-09T09:52:35
golang/go
aae088b16a327cc4b1a81928c307d5bd6e54849b
b09478b9c98857715fcb55ef746ae231b0b7d935
doc/godebug: fix tipo Change-Id: Ib67d81d8e3aa33c6a506813194cc5710b3d5cdd0 Reviewed-on: https://go-review.googlesource.com/c/go/+/629575 Reviewed-by: Dmitri Shuralyov <dmitshur@google.com> Reviewed-by: Dmitri Shuralyov <dmitshur@golang.org> LUCI-TryBot-Result: Go LUCI <golang-scoped@luci-project-accounts.iam.gservicea...
[ { "path": "doc/godebug.md", "patch": "@@ -165,7 +165,7 @@ The possible values for `multipathtcp` are now:\n - \"3\": enable MPTCP on dialers only by default\n \n For Go 1.24, it now defaults to multipathtcp=\"2\", thus\n-enabled by default on listerners. Using multipathtcp=\"0\" reverts to the\n+enabled by ...
2024-11-19T03:26:38
ggml-org/llama.cpp
46dba9fce860d41ac545224623f27ac71f9d264a
de8f01c2d7fd6ee7b642b3d09b1c5f1f9f6965fb
vulkan: fix flash attention dot product precision (#20589)
[ { "path": "ggml/src/ggml-vulkan/vulkan-shaders/flash_attn.comp", "patch": "@@ -245,7 +245,7 @@ void main() {\n #endif\n }\n [[unroll]] for (uint32_t r = 0; r < rows_per_thread; ++r) {\n- Sf[r][c] += ACC_TYPE(dot(Q_cache[r], K_Tf));\n+ ...
2026-03-16T09:45:49
electron/electron
ddd66543f72b9a4296b8f9094b1667055d130bd6
f4548985f481691d40352b6e12b9c41277cf992c
docs: explicitly allow string for MessageBoxOptions.icon (#32422) Fixes #32390. See #19782 for context.
[ { "path": "docs/api/dialog.md", "patch": "@@ -285,7 +285,7 @@ If `browserWindow` is not shown dialog will not be attached to it. In such case\n include a checkbox with the given label.\n * `checkboxChecked` boolean (optional) - Initial checked state of the\n checkbox. `false` by default.\n- * `ic...
2022-01-13T01:30:15
vuejs/vue
f7db7f361b6356591781b9f33abbb0d5b7f9b97c
0b3cf7dda9ac605b2b9f799acacd2793e974f225
fix(types): fix spreading VNodeData in tsx (#12789) fix #12778
[ { "path": "types/test/vue-test.ts", "patch": "@@ -228,21 +228,21 @@ obj.a++\n const ComponentWithStyleInVNodeData = Vue.extend({\n render(h) {\n const elementWithStyleAsString = h('div', {\n- style: 'background-color: red;'\n+ style: '--theme-color: black;'\n })\n \n- const elementWit...
2022-11-09T09:34:55
golang/go
b09478b9c98857715fcb55ef746ae231b0b7d935
3e7cb78800c662b36f9aebf9312ab25b42c2da2a
mime: disable TestLookupMallocs with ASAN With the synchashtriemap GOEXPERIMENT, this allocates now, but just under ASAN. That's OK, just skip the test under ASAN. Fixes #70428. Change-Id: I1ab4f7c06505c84309946358643715085f0db506 Reviewed-on: https://go-review.googlesource.com/c/go/+/629456 Reviewed-by: Cherry Mui ...
[ { "path": "src/mime/type_test.go", "patch": "@@ -5,6 +5,7 @@\n package mime\n \n import (\n+\t\"internal/asan\"\n \t\"slices\"\n \t\"strings\"\n \t\"sync\"\n@@ -143,6 +144,9 @@ func TestExtensionsByType(t *testing.T) {\n }\n \n func TestLookupMallocs(t *testing.T) {\n+\tif asan.Enabled {\n+\t\tt.Skip(\"test...
2024-11-18T22:16:57
electron/electron
f4548985f481691d40352b6e12b9c41277cf992c
506d82a90221905a1380b8b848e0e44f5300a4f3
fix: use setAspectRatio for frameless window on mac (#32287) * fix(window): setAspectRatio for frameless windows * dummy * undo dummy Co-authored-by: Jeremy Rose <nornagon@nornagon.net>
[ { "path": "shell/browser/native_window_mac.mm", "patch": "@@ -1600,10 +1600,15 @@ void ViewDidMoveToSuperview(NSView* self, SEL _cmd) {\n NativeWindow::SetAspectRatio(aspect_ratio, extra_size);\n \n // Reset the behaviour to default if aspect_ratio is set to 0 or less.\n- if (aspect_ratio > 0.0)\n- ...
2022-01-13T00:42:42
ollama/ollama
5930aaeb1ae420eb9a0963247ff4463d1eadce5a
faf67db089c6b2168fb1bab99b4385d374c64efe
cmd: fix cursor flickering in progress bar The previous commit fixed flickering in the progress bar itself. Cursor flickering is harder to address. Cursor flickering could be fixed by hiding the cursor altogether while the progress bar is displayed. The downside of this is that if the program is killed in such a way ...
[ { "path": "progress/progress.go", "patch": "@@ -1,6 +1,7 @@\n package progress\n \n import (\n+\t\"bytes\"\n \t\"fmt\"\n \t\"io\"\n \t\"sync\"\n@@ -12,8 +13,9 @@ type State interface {\n }\n \n type Progress struct {\n-\tmu sync.Mutex\n-\tw io.Writer\n+\tmu sync.Mutex\n+\tw io.Writer\n+\tbuf bytes.Buffe...
2025-02-17T22:55:32
ggml-org/llama.cpp
d3936498a3d8f41cdb35d9e7d04a19e704b4fc89
34818ea6c0e91a2fa245ce866f7e002a4a9cd381
common : fix iterator::end() dereference (#20445)
[ { "path": "common/regex-partial.cpp", "patch": "@@ -102,7 +102,7 @@ std::string regex_to_reversed_partial_regex(const std::string & pattern) {\n auto is_star = *it == '*';\n ++it;\n if (is_star) {\n- if (*it == '?') {\n+ i...
2026-03-16T06:50:38
huggingface/transformers
0294359061c39dfa9f7e64d8eacf4fd7fb173aab
07aed9d72889218ef2323dc7f02e4bfdf8b94677
[Docs] Complete missing Llama4 configuration docs (#43460) * [Docs]: Complete missing docs for Llama4Config * fix: Apply ruff formatting again * [Docs] Fix type hints (moe_layers list, floats) and style * [Docs] Updated docstring to describe the functional impact of certain parameters instead of raw definition ---...
[ { "path": "src/transformers/models/llama4/configuration_llama4.py", "patch": "@@ -56,15 +56,22 @@ class Llama4VisionConfig(PreTrainedConfig):\n The size (resolution) of each patch.\n norm_eps (`float`, *optional*, defaults to 1e-05):\n The epsilon used by the layer normalizat...
2026-02-02T16:52:40
vuejs/vue
0b3cf7dda9ac605b2b9f799acacd2793e974f225
a5afc4d0a4bfb9a777ac39b942edb932aad71097
fix(types): stricter type condition for `EventHandlers` (#12840) fix #12832
[ { "path": "types/jsx.d.ts", "patch": "@@ -1297,7 +1297,9 @@ export interface Events {\n }\n \n type EventHandlers<E> = {\n- [K in keyof E]?: E[K] extends Function ? E[K] : (payload: E[K]) => void\n+ [K in keyof E]?: E[K] extends (...args: any) => any\n+ ? E[K]\n+ : (payload: E[K]) => void\n }\n \n t...
2022-11-09T09:25:28
ollama/ollama
faf67db089c6b2168fb1bab99b4385d374c64efe
8cf16063a52deb416e16039c73264e26f7e9a43a
cmd: fix progress bar flickering Previous code cleared the display before writing new content, creating a window where the terminal could (and in some cases did) render empty lines. Instead, we now write new content over the old content, only clearing the trailing end of lines for cases where the new line is shorter....
[ { "path": "progress/progress.go", "patch": "@@ -84,17 +84,16 @@ func (p *Progress) render() {\n \tfmt.Fprint(p.w, \"\\033[?25l\")\n \tdefer fmt.Fprint(p.w, \"\\033[?25h\")\n \n-\t// clear already rendered progress lines\n-\tfor i := range p.pos {\n-\t\tif i > 0 {\n-\t\t\tfmt.Fprint(p.w, \"\\033[A\")\n-\t\t}...
2025-02-17T21:37:40
golang/go
3e7cb78800c662b36f9aebf9312ab25b42c2da2a
5432cd96fd951bce01bbce9f9744b62871f79b17
cmd/go: re-enable build JSON from go test -json, now with GODEBUG This re-enables the behavior of CL 536399 (by effectively reverting CL 628955), so now go test -json again includes build output and failures as JSON rather than text. However, since this behavior is clearly enough to trip up some build systems, this C...
[ { "path": "doc/godebug.md", "patch": "@@ -168,6 +168,14 @@ For Go 1.24, it now defaults to multipathtcp=\"2\", thus\n enabled by default on listerners. Using multipathtcp=\"0\" reverts to the\n pre-Go 1.24 behavior.\n \n+Go 1.24 changed the behavior of `go test -json` to emit build errors as JSON\n+instead ...
2024-11-18T19:56:43
ggml-org/llama.cpp
9e2e2198b006b5bcb81846a43b868528ea79a483
88915cb55c14769738fcab7f1c6eaa6dcc9c2b0c
tools/cli: fix disable reasoning (#20606)
[ { "path": "tools/cli/cli.cpp", "patch": "@@ -215,7 +215,7 @@ struct cli_context {\n inputs.parallel_tool_calls = false;\n inputs.add_generation_prompt = true;\n inputs.reasoning_format = COMMON_REASONING_FORMAT_DEEPSEEK;\n- inputs.enable_thinking = common_chat_tem...
2026-03-15T21:40:53
huggingface/transformers
07aed9d72889218ef2323dc7f02e4bfdf8b94677
751cff7c2cf564e551f6a779970a0ee285f90cdf
Fix t5 failures (#43374) * set eos_token_id in GenerationConfig * fix expectation * pop wo from dtype_plan when for bfloat16 * fix another expectation (same for amd & nvidia) * last one * fix repo-consistency * fix * override post_init() instead of __init__() * use _keep_in_fp32_modules in from_pretrained() wh...
[ { "path": "src/transformers/integrations/executorch.py", "patch": "@@ -879,6 +879,7 @@ def __init__(\n \"batch_size\": batch_size,\n \"max_cache_len\": max_cache_length,\n },\n+ eos_token_id=model.generation_config.eos_token_id,\n )\n se...
2026-02-02T16:43:54
electron/electron
99ee1fc0eba003e6d5791e11880fa6c06e509a59
cbe68bdbb875c6ce963e2b8ee1cd930fb44ad4f0
fix: will-attach-webview handler modifying params.instanceId does not break <webview> (#32386)
[ { "path": "lib/browser/guest-view-manager.ts", "patch": "@@ -73,6 +73,17 @@ function makeWebPreferences (embedder: Electron.WebContents, params: Record<stri\n return webPreferences;\n }\n \n+function makeLoadURLOptions (params: Record<string, any>) {\n+ const opts: Electron.LoadURLOptions = {};\n+ if (p...
2022-01-12T07:41:20
vuejs/vue
a5afc4d0a4bfb9a777ac39b942edb932aad71097
6d9aac8bd38f6d30a6db70b51fa46f27cbeac559
chore: fix typo (#12863)
[ { "path": "packages/compiler-sfc/test/compileScript.spec.ts", "patch": "@@ -1571,7 +1571,7 @@ describe('SFC analyze <script> bindings', () => {\n </script>\n <template>\n <div @click=\"$emit('update:a');\"></div>\n- </tempalte>\n+ </template>\n `)\n })\n })", "a...
2022-11-09T08:07:36
ggml-org/llama.cpp
88915cb55c14769738fcab7f1c6eaa6dcc9c2b0c
ebbf544ed1008e8643add8d7cccd96516b14fa48
server : fix wait in test_cancel_requests() test (#20601) * server : fix wait in test_cancel_requests() test * codeowners : add team for server tests
[ { "path": "CODEOWNERS", "patch": "@@ -85,6 +85,7 @@\n /tools/quantize/ @ggerganov\n /tools/rpc/ @ggml-org/ggml-rpc\n /tools/server/* @ggml-org/llama-server # no subdir\n+/tools/server/tests/ @ggml-org/llama-server\...
2026-03-15T18:54:37
golang/go
ec7824b6bb12481e7ffe50b7f1cbaa1faf465a44
79c0041daf1649a1b5374e7f59689558b67a969d
cmd/go: disable fuzz instrumentation for internal/godebug This is thought to be the cause of certain recent longtest failures. Let's try it out. This appears to fix the longtests fuzz failures. I suspect that the sync.Map in internal/godebug is at fault with the implementation changing. I'm not sure yet exactly why t...
[ { "path": "src/cmd/go/internal/test/test.go", "patch": "@@ -933,7 +933,9 @@ func runTest(ctx context.Context, cmd *base.Command, args []string) {\n \t\tvar skipInstrumentation = map[string]bool{\n \t\t\t\"context\": true,\n \t\t\t\"internal/fuzz\": true,\n+\t\t\t\"internal/godebug\": ...
2024-11-18T22:23:43
ollama/ollama
0667baddc658d3f556a369701819e7695477f59a
d006e1e09be4d3da3fb94ab683aa18822af4b956
docs: fix incorrect shortcut key in windows.md (#9098)
[ { "path": "docs/windows.md", "patch": "@@ -55,7 +55,7 @@ Here's a quick example showing API access from `powershell`\n ## Troubleshooting\n \n Ollama on Windows stores files in a few different locations. You can view them in\n-the explorer window by hitting `<cmd>+R` and type in:\n+the explorer window by h...
2025-02-15T20:38:24
electron/electron
2bbba9e2423bf6e99dc7c4269cc4caf4572f7548
94db8cd45ecb7a7d149ca73ad2ab0206cac5a9aa
chore: fix incorrect usage of reference (#32413)
[ { "path": "patches/chromium/chore_provide_iswebcontentscreationoverridden_with_full_params.patch", "patch": "@@ -108,7 +108,7 @@ index 6688ba8ba2fb7d930773144cdbc43f1f6fa2b685..22015c7b9b50e1264551ce226757f90e\n }\n \n diff --git a/chrome/browser/ui/browser.cc b/chrome/browser/ui/browser.cc\n-index da52...
2022-01-12T07:39:30
huggingface/transformers
751cff7c2cf564e551f6a779970a0ee285f90cdf
645db400b69e66867f0c011c0ab900042fc0ac6d
Add EoMT with DINOv3 backbone (#41212) * Add EoMT DINOv3 model * Add EoMT-DINOv3 conversion script * Refine EoMT-DINOv3 conversion to support timm backbones * Fix DINOv3 conversion key mapping * Add debug trace for EoMT-DINOv3 verification * Fix EoMT-DINOv3 verification mapping * Remove script * Fix attention m...
[ { "path": "docs/source/en/_toctree.yml", "patch": "@@ -827,6 +827,8 @@\n title: EfficientNet\n - local: model_doc/eomt\n title: EoMT\n+ - local: model_doc/eomt_dinov3\n+ title: EoMT-DINOv3\n - local: model_doc/focalnet\n title: FocalNet\n - local: model_...
2026-02-02T16:09:04
vuejs/vue
6d9aac8bd38f6d30a6db70b51fa46f27cbeac559
a7a71ad99071c8c48ae9c106a19f81e70ded4898
chore: fix some broken links to v2 docs (#12839)
[ { "path": "examples/classic/elastic-header/index.html", "patch": "@@ -32,7 +32,7 @@\n <draggable-header-view>\n <template slot=\"header\">\n <h1>Elastic Draggable SVG Header</h1>\n- <p>with <a href=\"https://vuejs.org\">Vue.js</a> + <a href=\"http://dynamicsjs.com\">dynamics...
2022-10-19T04:45:59
ggml-org/llama.cpp
ebbf544ed1008e8643add8d7cccd96516b14fa48
b91d7dfe5bb3745147ee3a5f18be8d4f803b0e84
sycl : fix for untransposed GDA recurrent state (#20583)
[ { "path": "ggml/src/ggml-sycl/gated_delta_net.cpp", "patch": "@@ -55,7 +55,7 @@ void gated_delta_net_sycl(const float * q,\n #pragma unroll\n for (int r = 0; r < rows_per_lane; r++) {\n const int i = r * warp_size + lane;\n- s_shard[r] = curr_state[i * S_v + col];\n+ s_shard[r...
2026-03-15T18:10:15
ollama/ollama
f05774b04c5d3d30c6f3037a5a14595bf57a16ad
6600bd7d91deb07bec5832790168870c3180ccae
llm: do not evaluate symlink for exe path lookup (#9088) In some cases, the directories in the executable path read by filepath.EvalSymlinks are not accessible, resulting in permission errors which results in an error when running models. It also doesn't work well on long paths on windows, also resulting in errors...
[ { "path": "discover/path.go", "patch": "@@ -19,11 +19,6 @@ var LibOllamaPath string = func() string {\n \t\treturn \"\"\n \t}\n \n-\texe, err = filepath.EvalSymlinks(exe)\n-\tif err != nil {\n-\t\treturn \"\"\n-\t}\n-\n \tvar libPath string\n \tswitch runtime.GOOS {\n \tcase \"windows\":", "additions": ...
2025-02-14T06:13:00
golang/go
ecdc8c1b3f54367338de37174531f81574c791b2
cf531372b24c926db21e7eeac6e8066f0c604368
crypto/internal/cryptotest: add SkipTestAllocations [ ] [ It has been [ 0 ] days since Filippo broke a TestAllocations. ] [ ] Concentrate all the skips in one place, so we don'...
[ { "path": "src/crypto/ed25519/ed25519_test.go", "patch": "@@ -9,11 +9,10 @@ import (\n \t\"bytes\"\n \t\"compress/gzip\"\n \t\"crypto\"\n-\t\"crypto/internal/boring\"\n+\t\"crypto/internal/cryptotest\"\n \t\"crypto/rand\"\n \t\"crypto/sha512\"\n \t\"encoding/hex\"\n-\t\"internal/testenv\"\n \t\"log\"\n \t\"...
2024-11-08T13:41:06
huggingface/transformers
fb22e73f322d38ec2ccd9d5c76f9c27aab288b45
010b9f1e64ea29bf071da2437809b6147cde5e26
[loading] Fix forced upcasting to fp32 (#43683) * start * fix * add strict tests * small fixes * stricter * fix * fix * small typo * improve signature
[ { "path": "src/transformers/core_model_loading.py", "patch": "@@ -40,7 +40,7 @@\n \n if TYPE_CHECKING:\n from .integrations.tensor_parallel import TensorParallelLayer\n- from .modeling_utils import PreTrainedModel\n+ from .modeling_utils import LoadStateDictConfig, PreTrainedModel\n from .quan...
2026-02-02T15:39:37
vuejs/vue
259c7060da72ea3040fc8c3de4ecb823ad5059f4
df281b0e4c400be18df8bcf4e83df8b25a81e21b
chore: fix changelog rendering [ci skip]
[ { "path": "CHANGELOG.md", "patch": "@@ -888,7 +888,7 @@ In addition:\n - **compiler:** wrap scoped slots v-if conditions in parens ([#9119](https://github.com/vuejs/vue/issues/9119)) ([ef8524a](https://github.com/vuejs/vue/commit/ef8524ab7db8d64ac449ce74f5858aa9d91357ad)), closes [#9114](https://github.com/...
2022-10-15T09:39:04
ollama/ollama
7e13f568dc632fa61c8f92605a34c5700e834f44
58245413f4df1c56d7e5f03ab6ff20dfafb8daa1
backend: Don't return an error on Close It is not common to return errors with close/free operations - most people won't check it and even if they did there's probably not much that can do. It's better to not give implementations false expectations.
[ { "path": "ml/backend.go", "patch": "@@ -50,7 +50,7 @@ type Context interface {\n \n \tForward(Tensor)\n \tCompute(Tensor) Tensor\n-\tClose() error\n+\tClose()\n }\n \n type Tensor interface {", "additions": 1, "deletions": 1, "language": "Go" }, { "path": "ml/backend/ggml/ggml.go", ...
2025-02-05T03:49:34
electron/electron
b0f315a637b05bc445fc7e6084baa840891c1207
483808a8cf0db0417ca10383c13923898ce4fc0a
chore: bump chromium to 99.0.4767.0 (main) (#31986) * chore: bump chromium in DEPS to 98.0.4726.0 * 3292117: Remove unneeded base/compiler_specific.h includes in //chrome. https://chromium-review.googlesource.com/c/chromium/src/+/3292117 * 3289198: Enables calculating line, word and sentence boundaries on the...
[ { "path": "BUILD.gn", "patch": "@@ -556,6 +556,7 @@ source_set(\"electron_lib\") {\n defines += [\n # Disable warnings for g_settings_list_schemas.\n \"GLIB_DISABLE_DEPRECATION_WARNINGS\",\n+ \"USE_X11=1\",\n ]\n \n sources += [", "additions": 1, "deletions": 0, "lan...
2022-01-10T22:31:39
ggml-org/llama.cpp
8b7d340b6ffbb1bc47093f5b4b840bc2ff996a75
559646472d4b0ab732b977fefeebc3c38eae458b
ggml/hip: fix APU compatibility - soft error handling for hipMemAdviseSetCoarseGrain (#20536) * ggml/hip: fix APU compatibility - soft error handling for hipMemAdviseSetCoarseGrain On AMD APU/iGPU devices (unified memory architecture), hipMemAdviseSetCoarseGrain returns hipErrorInvalidValue because the hint is not ap...
[ { "path": "ggml/src/ggml-cuda/ggml-cuda.cu", "patch": "@@ -124,7 +124,10 @@ static cudaError_t ggml_cuda_device_malloc(void ** ptr, size_t size, int device)\n err = cudaMallocManaged(ptr, size);\n #if defined(GGML_USE_HIP)\n if (err == hipSuccess) {\n- CUDA_CHECK(cudaMemAdvise(*pt...
2026-03-15T16:23:58
huggingface/transformers
010b9f1e64ea29bf071da2437809b6147cde5e26
0fa2c2f06f91129b89462e0136c0a25618e1a31b
Fix FP8Expert for Qwen (#43670) fix FP8Expert for Qwen Signed-off-by: yiliu30 <yi4.liu@intel.com>
[ { "path": "src/transformers/integrations/finegrained_fp8.py", "patch": "@@ -625,7 +625,7 @@ def __init__(self, config, block_size, dtype=torch.float8_e4m3fn):\n from ..activations import ACT2FN\n \n self.block_size = block_size\n- self.num_experts = config.num_local_experts\n+ ...
2026-02-02T15:18:04
vuejs/vue
800207c473c7d6dfcdc883100a3d443fc5ad2e39
5960f05c69099c174062b6672c7a21d717a3bccf
fix(effectScope): calling off() of a detached scope should not break currentScope fix #12825
[ { "path": "src/v3/reactivity/effectScope.ts", "patch": "@@ -16,9 +16,7 @@ export class EffectScope {\n * @internal\n */\n cleanups: (() => void)[] = []\n-\n /**\n- * only assigned by undetached scope\n * @internal\n */\n parent: EffectScope | undefined\n@@ -38,9 +36,9 @@ export class Eff...
2022-10-14T02:51:07
ollama/ollama
378d6e1e6a94099a60d6b7ce99971bbf536bc34d
afa55bc70cb1714fcad10571279a42109a6e0631
docs: fix nix package link (#9045) removing the channel tag from the url so it will always go to the current stable channel.
[ { "path": "README.md", "patch": "@@ -439,7 +439,7 @@ See the [API documentation](./docs/api.md) for all endpoints.\n - [Gentoo](https://github.com/gentoo/guru/tree/master/app-misc/ollama)\n - [Helm Chart](https://artifacthub.io/packages/helm/ollama-helm/ollama)\n - [Guix channel](https://codeberg.org/tushar...
2025-02-12T17:16:26
ggml-org/llama.cpp
559646472d4b0ab732b977fefeebc3c38eae458b
cf45437d35eecd3f05a21968a4958a50e8038fb6
fix: prevent nullptr dereference (#20552)
[ { "path": "common/chat-diff-analyzer.cpp", "patch": "@@ -479,6 +479,7 @@ analyze_content::analyze_content(const common_chat_template & tmpl, const analyz\n \n if (!comparison_with_tools || !comparison_with_reasoning) {\n LOG_DBG(ANSI_ORANGE \"%s: Template application failed\\n\" ANSI_RESET, __fu...
2026-03-15T15:51:49
electron/electron
483808a8cf0db0417ca10383c13923898ce4fc0a
746927c972869863c2a0a3a72f9a3f2c0ff3a731
fix: Support running git-[im,ex]port-patches with Python3 too (#32303) * script: Python3 compatibility for utf8 conversion The unicode() method has been renamed to str() in Python3, add a wrapper around it to support running against both versions. * script: don't require python2 for git-[import,export]-patches ...
[ { "path": "script/git-export-patches", "patch": "@@ -1,4 +1,4 @@\n-#!/usr/bin/env python2\n+#!/usr/bin/env python\n \n import argparse\n import sys", "additions": 1, "deletions": 1, "language": "Unknown" }, { "path": "script/git-import-patches", "patch": "@@ -1,4 +1,4 @@\n-#!/usr/bin...
2022-01-10T21:47:55
golang/go
c4aea467842efc3baf6cd2f5ad19fe23d7304c2e
0240c91383fb5bdbdc2676637662db95e87b77db
crypto/aes: move to crypto/internal/fips/aes The crypto/aes <-> crypto/cipher interfaces and the hardware support upgrades were layered over the years, and had grown unwieldily. Before: conditionally wrap the private crypto/aes type in private types that implement an interface that's interface-upgraded by crypto/ciph...
[ { "path": "src/crypto/aes/aes.go", "patch": "@@ -0,0 +1,48 @@\n+// Copyright 2009 The Go Authors. All rights reserved.\n+// Use of this source code is governed by a BSD-style\n+// license that can be found in the LICENSE file.\n+\n+// Package aes implements AES encryption (formerly Rijndael), as defined in\...
2024-11-01T10:46:34
vuejs/vue
5960f05c69099c174062b6672c7a21d717a3bccf
8e262618cdc3251ca9630b17de4a000567ffb007
fix(watch): avoid traversing objects that are marked non-reactive (#12806)
[ { "path": "src/core/observer/traverse.ts", "patch": "@@ -21,6 +21,7 @@ function _traverse(val: any, seen: SimpleSet) {\n const isA = isArray(val)\n if (\n (!isA && !isObject(val)) ||\n+ val.__v_skip /* ReactiveFlags.SKIP */ ||\n Object.isFrozen(val) ||\n val instanceof VNode\n ) {", ...
2022-10-12T13:25:26
huggingface/transformers
0fa2c2f06f91129b89462e0136c0a25618e1a31b
e5c8b0d14a8d9822d684b92072b93c4c3422b0cb
Simplify loading structure (#43589) * start a bit more more better better better fix use set fix default doc fix doc fix * fix tests * fix * rename * small fix * colors
[ { "path": "src/transformers/core_model_loading.py", "patch": "@@ -20,7 +20,7 @@\n import re\n from abc import abstractmethod\n from collections import defaultdict\n-from collections.abc import Callable, MutableMapping, MutableSet\n+from collections.abc import Callable\n from concurrent.futures import Future...
2026-02-02T13:28:39
ollama/ollama
afa55bc70cb1714fcad10571279a42109a6e0631
49df03da9af6b0050ebbf50676f7db569a2b54d9
doc: fix link for Abso (#9043)
[ { "path": "README.md", "patch": "@@ -494,7 +494,7 @@ See the [API documentation](./docs/api.md) for all endpoints.\n - [multi-llm-ts](https://github.com/nbonamy/multi-llm-ts) (A Typescript/JavaScript library allowing access to different LLM in unified API)\n - [LlmTornado](https://github.com/lofcz/llmtornad...
2025-02-12T17:15:08
ggml-org/llama.cpp
9cd4ebcfb1ceb3b4af6276089252dc27690e98ba
89d0aec0420f45718bc7f960134e7237dd4c9712
ci : split build.yml + server.yml (#20546) * ci : split build.yml * cont : split server.yml * cont : reduce paths * cont : split build-android.yml + update paths * ci : make msys workflows manual (#20588) * ci : make cross-build workflows manual (#20585) * cont : fix release paths Co-authored-by: Sigbjørn Skjær...
[ { "path": ".github/workflows/build-3rd-party.yml", "patch": "@@ -0,0 +1,57 @@\n+name: CI (3rd-party)\n+\n+on:\n+ workflow_dispatch: # allows manual triggering\n+ push:\n+ branches:\n+ - master\n+ paths: [\n+ '.github/workflows/build-3rd-party.yml',\n+ '**/CMakeLists.txt',\n+ '**/...
2026-03-15T13:11:17
golang/go
0240c91383fb5bdbdc2676637662db95e87b77db
170436c045f1303543e6d0bf8b36fccac57da2cd
crypto/aes: speedup CTR mode on AMD64 and ARM64 The implementation runs up to 8 AES instructions in different registers one after another in ASM code. Because CPU has instruction pipelining and the instructions do not depend on each other, they can run in parallel with this layout of code. This results in significant ...
[ { "path": "src/crypto/aes/_asm/ctr/ctr_amd64_asm.go", "patch": "@@ -0,0 +1,127 @@\n+// Copyright 2024 The Go Authors. All rights reserved.\n+// Use of this source code is governed by a BSD-style\n+// license that can be found in the LICENSE file.\n+\n+package main\n+\n+import (\n+\t\"fmt\"\n+\t\"sync\"\n+\n...
2024-02-08T01:27:16
electron/electron
746927c972869863c2a0a3a72f9a3f2c0ff3a731
7c16ef1f62b3ba738de00da932b97639b25dcdd5
feat: Add `first-instance-ack` event to the `app.requestSingleInstanceLock()` flow (#31460) * feat: Add onFirstInstanceAck event for requestSingleInstanceLock * Add tests * Apply patch fix * Add back missing docs * Rebase * Listen for exit earlier in test * Rebase
[ { "path": "docs/api/app.md", "patch": "@@ -484,6 +484,7 @@ Returns:\n * `argv` string[] - An array of the second instance's command line arguments\n * `workingDirectory` string - The second instance's working directory\n * `additionalData` unknown - A JSON object of additional data passed from the second in...
2022-01-10T16:54:46
vuejs/vue
8e262618cdc3251ca9630b17de4a000567ffb007
4cad41007174a7eeebf4472ddbd7b3b693db03f1
fix(types): style attribute svg (#12800) Set style attribute on svg to use `StyleValue`
[ { "path": "types/jsx.d.ts", "patch": "@@ -731,7 +731,7 @@ export interface SVGAttributes extends AriaAttributes, EventHandlers<Events> {\n * @see https://www.w3.org/TR/SVG/styling.html#ElementSpecificStyling\n */\n class?: any\n- style?: string | CSSProperties\n+ style?: StyleValue\n \n color?: ...
2022-10-12T13:24:26
huggingface/transformers
5ccea2304ec48c814038cfcdd57e1373d95b0cf8
8fce0a18de037689384bc4b21da5107127eda539
Make sure hub errors are surfaced in `PreTrainedTokenizerBase` (#43675) In `PreTrainedTokenizerBase.from_pretrained` this commit 73a13f8 had a dry try/except that was hiding possible hub issues.
[ { "path": "src/transformers/tokenization_utils_base.py", "patch": "@@ -1613,29 +1613,26 @@ def from_pretrained(\n # Check for versioned tokenizer files\n if \"tokenizer_file\" in vocab_files:\n fast_tokenizer_file = FULL_TOKENIZER_FILE\n- try:\n- ...
2026-02-02T12:40:46
ollama/ollama
49df03da9af6b0050ebbf50676f7db569a2b54d9
0189bdd0b79fceab9e801a63e1311d53f3784dbc
fix: harden backend loading (#9024) * wrap ggml_backend_load_best in try/catch * ignore non-ollama paths
[ { "path": "llama/patches/0017-try-catch-backend-load.patch", "patch": "@@ -0,0 +1,69 @@\n+From 0000000000000000000000000000000000000000 Mon Sep 17 00:00:00 2001\n+From: Michael Yang <mxyng@pm.me>\n+Date: Tue, 11 Feb 2025 14:06:36 -0800\n+Subject: [PATCH] try/catch backend load\n+\n+---\n+ ggml/src/ggml-back...
2025-02-11T23:36:53
ggml-org/llama.cpp
6b10a82c00064d4ead889b09d7fae9eff6927d57
d23355afc319f598d0e588a2d16a4da82e14ff41
kv-cache : fix reading llama_kv_cell_ext during state read (#20273) Co-authored-by: sid <sid@ragingfist.net>
[ { "path": "src/llama-kv-cache.cpp", "patch": "@@ -1953,6 +1953,12 @@ bool llama_kv_cache::state_read_meta(llama_io_read_i & io, uint32_t strm, uint32\n \n cells.pos_set(i, pos);\n \n+ if (hparams.n_pos_per_embd() > 1) {\n+ llama_kv_cell_ext ext;\n+ io.rea...
2026-03-15T07:11:19
golang/go
170436c045f1303543e6d0bf8b36fccac57da2cd
b8fe88393b122a06e00163dc464bf8cd14187f4b
cmd/compile: strongly favor closure inlining This tweaks the inlining cost knob for closures specifically, they receive a doubled budget. The rationale for this is that closures have a lot of "crud" in their IR that will disappear after inlining, so the standard budget penalizes them unnecessarily. This is also the ...
[ { "path": "src/cmd/cgo/internal/test/callback_windows.go", "patch": "@@ -69,11 +69,11 @@ func testCallbackCallersSEH(t *testing.T) {\n \twant := []string{\n \t\t\"test._Cfunc_backtrace\",\n \t\t\"test.testCallbackCallersSEH.func1.1\",\n-\t\t\"test.testCallbackCallersSEH.func1\",\n+\t\t// \"test.testCallback...
2024-11-15T22:08:34
vuejs/vue
e80cd09fff570df57d608f8f5aaccee6d7f31917
c61395d3f1ed926d2783d8460970ed20ea01dc4f
Revert "fix(setup): setup hook should be called before beforeCreate" This reverts commit e1342df7847a51c75192fec74e94378178e046b0. reopen #12802 close #12821 close #12822
[ { "path": "src/core/instance/init.ts", "patch": "@@ -1,6 +1,6 @@\n import config from '../config'\n import { initProxy } from './proxy'\n-import { initProps, initState } from './state'\n+import { initState } from './state'\n import { initRender } from './render'\n import { initEvents } from './events'\n imp...
2022-10-12T13:22:26
electron/electron
bd861e50799326e2fe9a793f58a0fe0422a925f0
cb2c1f888ece495a131c4729759a70ab9d018462
docs: fix note for `will-move` event (#32362)
[ { "path": "docs/api/browser-window.md", "patch": "@@ -556,7 +556,7 @@ Returns:\n \n Emitted before the window is moved. On Windows, calling `event.preventDefault()` will prevent the window from being moved.\n \n-Note that this is only emitted when the window is being resized manually. Resizing the window wi...
2022-01-10T10:02:16
huggingface/transformers
8fce0a18de037689384bc4b21da5107127eda539
e4b22baa9b14560dc37657bd0109563a9bf3a4e3
Fix `FP8Expert` for DeepSeek R1 (#43616) * use moe_intermediate_size for ds Signed-off-by: yiliu30 <yi4.liu@intel.com> * format Signed-off-by: yiliu30 <yi4.liu@intel.com> --------- Signed-off-by: yiliu30 <yi4.liu@intel.com> Co-authored-by: Mohamed Mekkouri <93391238+MekkCyber@users.noreply.github.com>
[ { "path": "src/transformers/integrations/finegrained_fp8.py", "patch": "@@ -627,7 +627,9 @@ def __init__(self, config, block_size, dtype=torch.float8_e4m3fn):\n self.block_size = block_size\n self.num_experts = config.num_local_experts\n self.hidden_dim = config.hidden_size\n- ...
2026-02-02T11:55:15
ollama/ollama
f4711da7bd88f237bec7a5271facb27a107726f0
38117fba83c8291e28abe564d56600c200ff4cab
ml/backend/ggml: fix crash on dlopen for non-AVX systems (#8976)
[ { "path": "llama/patches/0016-remove-sgemm-global-variables.patch", "patch": "@@ -0,0 +1,55 @@\n+From 0000000000000000000000000000000000000000 Mon Sep 17 00:00:00 2001\n+From: jmorganca <jmorganca@gmail.com>\n+Date: Sun, 9 Feb 2025 17:22:15 -0800\n+Subject: [PATCH] remove sgemm global variables\n+\n+removes...
2025-02-10T17:52:12
ggml-org/llama.cpp
609ea50026a336a6cf3c02e596792477530b5928
9f774e45eea7bc2883920643281b26902c96e6bd
hexagon: Q4_0 and MXFP4 repack fixes (#20527) * hexagon: fix tail corruption with rows sizes not multiple of 256 * hexagon: use different stride for repacking partial blocks * hex-mm: update repack and kernels to avoid shuffles for full 256-element blocks Previous commit changed the repacking to use even:odd (0:1,2...
[ { "path": "ggml/src/ggml-hexagon/ggml-hexagon.cpp", "patch": "@@ -402,6 +402,7 @@ static void pack_q4_0_quants(block_q4_0 * x, const uint8_t * qs, unsigned int bi\n static void repack_row_q4x4x2(uint8_t * y, const block_q4_0 * x, int64_t k) {\n static const int qk = QK_Q4_0x4x2;\n const int n...
2026-03-14T18:09:08
golang/go
b8fe88393b122a06e00163dc464bf8cd14187f4b
a65f1a467ff6a10dc6688f292dfa8a2e08cc1eb4
os: correctly handle errno==0 in (*Process).blockUntilWaitable CL 627478 inadvertently returns a non-nil error containing a syscall.Errno(0). Change-Id: I1d6a9d0575d3ed651ddc02f30505437d0d266bb3 Reviewed-on: https://go-review.googlesource.com/c/go/+/629515 Auto-Submit: Ian Lance Taylor <iant@google.com> LUCI-TryBot-R...
[ { "path": "src/os/wait_wait6.go", "patch": "@@ -17,7 +17,10 @@ import (\n func (p *Process) blockUntilWaitable() (bool, error) {\n \terr := ignoringEINTR(func() error {\n \t\t_, errno := wait6(_P_PID, p.Pid, syscall.WEXITED|syscall.WNOWAIT)\n-\t\treturn errno\n+\t\tif errno != 0 {\n+\t\t\treturn errno\n+\t\...
2024-11-18T22:39:20
vuejs/vue
738f4b3c570dc3a1818924a203a9f8e4b1ec90f0
cc14d4452c66e90341b7f9a5cdd2b7acffa529e9
fix(build): enforce LF line ending in built files fix #12819
[ { "path": "dist/vue.runtime.mjs", "patch": "@@ -1,76 +1,76 @@\n-import Vue from './vue.runtime.common.js'\r\n-export default Vue\r\n-\r\n-// this should be kept in sync with src/v3/index.ts\r\n-export const {\r\n- version,\r\n-\r\n- // refs\r\n- ref,\r\n- shallowRef,\r\n- isRef,\r\n- toRef,\r\n- toRe...
2022-10-11T09:51:46
huggingface/transformers
4cd791d6eeaf4fa4cc49c74d572b281c0e291762
b9f0074f800e4ee71bb55b1caf77d97054285e09
[`HunYuan`] Fix RoPE init (#43411) fix
[ { "path": "src/transformers/models/hunyuan_v1_dense/modeling_hunyuan_v1_dense.py", "patch": "@@ -26,6 +26,7 @@\n \n from transformers.cache_utils import Cache\n \n+from ... import initialization as init\n from ...activations import ACT2FN\n from ...cache_utils import DynamicCache\n from ...generation import...
2026-02-02T11:17:27
electron/electron
cb2c1f888ece495a131c4729759a70ab9d018462
6d8a858897d66725b5a56cfccbd0fe76ae125c90
fix: incorrect `skipTransformProcessType` option parsing in `win.setVisibleOnAllWorkspaces()` (#32364)
[ { "path": "shell/browser/api/electron_api_base_window.cc", "patch": "@@ -854,10 +854,10 @@ void BaseWindow::SetVisibleOnAllWorkspaces(bool visible,\n gin_helper::Dictionary options;\n bool visibleOnFullScreen = false;\n bool skipTransformProcessType = false;\n- args->GetNext(&options) &&\n- opti...
2022-01-10T10:00:28
ollama/ollama
1c198977ecdd471aee827a378080ace73c02fa8d
330b6c50b040d46b83cd66913a8b00df147a7e9b
ci: fix linux archive (#8862) the find returns intermediate directories which pulls the parent directories. it also omits files under lib/ollama. switch back to globbing
[ { "path": ".github/workflows/release.yaml", "patch": "@@ -303,24 +303,33 @@ jobs:\n steps:\n - uses: actions/checkout@v4\n - uses: docker/setup-buildx-action@v3\n+ - uses: docker/build-push-action@v6\n+ with:\n+ context: .\n+ platforms: ${{ matrix.os }}/${{ matr...
2025-02-06T03:45:58
ggml-org/llama.cpp
94d026227771ab6497a9900fe85847342f26071b
a93c0ef0fa9ad7b6afed0ac5245d854870b8685e
mtmd: add llama-mtmd-debug binary (#20508) * mtmd: add llama-mtmd-debug binary * adapt * fixes * fix compile error * fix windows compile error * rm legacy clip_debug_encode() * add MTMD_API to fix build
[ { "path": "tools/mtmd/CMakeLists.txt", "patch": "@@ -62,6 +62,10 @@ set_target_properties(mtmd\n PROPERTIES\n PUBLIC_HEADER \"${MTMD_PUBLIC_HEADERS}\")\n \n+set_target_properties(mtmd\n+ PROPERTIES\n+ PRIVATE_HEADER debug/mtmd-debug.h)\n+\n install(TARGETS mtmd LIBRARY PUBLIC_HEADER)\n \n if (...
2026-03-14T14:52:29
vuejs/vue
e1342df7847a51c75192fec74e94378178e046b0
0d6d972b32521fd18eb853b1073c0a19859a499a
fix(setup): setup hook should be called before beforeCreate fix #12802 Note this commit moves the initialization of injections and props to before the invocation of beforeCreate. This should not cause breakage because props and inject normalization has always been done before beforeCreate, so code that attempts to mo...
[ { "path": "src/core/instance/init.ts", "patch": "@@ -1,6 +1,6 @@\n import config from '../config'\n import { initProxy } from './proxy'\n-import { initState } from './state'\n+import { initProps, initState } from './state'\n import { initRender } from './render'\n import { initEvents } from './events'\n imp...
2022-10-11T08:23:08
electron/electron
824c909e2ac1c883252ef9229f4489a8fa515238
7678a0aebb0fc539e9be4e9aa568fcc1393ab819
fix: Allow npm_config_arch override on mac (#32266) If the npm_config_arch environment variable is set on Mac, then use the specified architecture rather than overriding it to x64.
[ { "path": "npm/install.js", "patch": "@@ -22,7 +22,8 @@ if (isInstalled()) {\n const platform = process.env.npm_config_platform || process.platform;\n let arch = process.env.npm_config_arch || process.arch;\n \n-if (platform === 'darwin' && process.platform === 'darwin' && arch === 'x64') {\n+if (platform =...
2022-01-07T08:53:15
huggingface/transformers
aeb728ab5c3ddfddefd8a198978983871a406ef9
5772c7333f4db6510611a3a11d043bdd1eae03d3
[`Sam`] Fixup training flags (#43567) * fixup flags * style * fix tests * fix
[ { "path": "tests/models/edgetam/test_modeling_edgetam.py", "patch": "@@ -148,7 +148,7 @@ def __init__(\n fpn_hidden_size=32,\n memory_encoder_hidden_size=32,\n batch_size=2,\n- is_training=False,\n+ is_training=True,\n ):\n self.parent = parent\n sel...
2026-02-02T11:12:18
golang/go
a65f1a467ff6a10dc6688f292dfa8a2e08cc1eb4
5e82cba9bdf45d81da549477d172f6b5e23106d4
weak: move internal/weak to weak, and update according to proposal The updates are: - API documentation changes. - Removal of the old package documentation discouraging linkname. - Addition of new package documentation with some advice. - Renaming of weak.Pointer.Strong -> weak.Pointer.Value. Fixes #67552. Change-Id...
[ { "path": "api/next/67552.txt", "patch": "@@ -0,0 +1,3 @@\n+pkg weak, func Make[$0 interface{}](*$0) Pointer[$0] #67552\n+pkg weak, method (Pointer[$0]) Value() *$0 #67552\n+pkg weak, type Pointer[$0 interface{}] struct #67552", "additions": 3, "deletions": 0, "language": "Plain Text" }, { ...
2024-11-15T20:42:32